/**********************************************************************************************/
/* OpenSi : Logiciel SaaS de gestion commerciale et comptabilit spcialis dans l'e-commerce */
/* Copyright (c) - Tous droits rservs - SAS Speedinfo Evolution                             */
/**********************************************************************************************/

jsLoader.loadSubScript("chrome://opensi/content/libs/profil.js");


var mainProfil = null;
var sessionId;


function init() {
	try {

		window.maximize();

  	var page = "chrome://opensi/content/utilisateurs/menu_utilisateurs.xul?"+ cookie();
  	document.getElementById("contenu").setAttribute("src",page);
    document.getElementById("login").value = ParamValeur("Utilisateur");

		if (ParamValeur("VTest")=="true") {
			document.getElementById("imgLogo").setAttribute("src", "chrome://opensi/content/design/logo-test-conf.svg");
		}

		document.getElementById("date_courante").value = getDateCourante();

		sessionId = ParamValeur("S_");

	} catch (e) {
    recup_erreur(e);
  }
}


function getProfil() {

	if (mainProfil==null) {
		mainProfil = new Profil();
	}

	return mainProfil;
}


function resetProfil() {

	mainProfil = null;
}


function getSessionId() {

	return sessionId;
}
